Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(231)

Unified Diff: recipes/dart.py

Issue 1157543005: Add fetch recipes for dart and dartium (Closed) Base URL: https://chromium.googlesource.com/chromium/tools/depot_tools.git@master
Patch Set: auto svn Created 5 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | recipes/dartium.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: recipes/dart.py
diff --git a/recipes/mojo.py b/recipes/dart.py
similarity index 75%
copy from recipes/mojo.py
copy to recipes/dart.py
index f7316ace9299b1066e1b315ba165fdf6fd372280..2b4d78c0f25b820b9e43b2e70512cd0051737434 100644
--- a/recipes/mojo.py
+++ b/recipes/dart.py
@@ -1,4 +1,4 @@
-# Copyright 2014 The Chromium Authors. All rights reserved.
+# Copyright 2015 The Chromium Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
@@ -9,14 +9,14 @@ import recipe_util # pylint: disable=F0401
# This class doesn't need an __init__ method, so we disable the warning
# pylint: disable=W0232
-class Mojo(recipe_util.Recipe):
- """Basic Recipe class for Mojo."""
+class Dart(recipe_util.Recipe):
+ """Basic Recipe class for Dart."""
@staticmethod
def fetch_spec(props):
- url = 'https://github.com/domokit/mojo.git'
+ url = 'https://github.com/dart-lang/sdk.git'
solution = {
- 'name' :'src',
+ 'name' :'sdk',
'url' : url,
'deps_file': 'DEPS',
'managed' : False,
@@ -35,11 +35,11 @@ class Mojo(recipe_util.Recipe):
@staticmethod
def expected_root(_props):
- return 'src'
+ return 'sdk'
def main(argv=None):
- return Mojo().handle_args(argv)
+ return Dart().handle_args(argv)
if __name__ == '__main__':
« no previous file with comments | « no previous file | recipes/dartium.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698